import React from 'react';
import { PoemForm } from '../components/PoemForm';
import { PoemDisplay } from '../components/PoemDisplay';
import { Logo } from '../components/Logo';
import { StaticHeader } from '../components/StaticHeader';
import { Footer } from '../components/Footer';
import { generateId, storage, scrollToPoem } from '../lib/utils';
import type { PoemFormData } from '../components/PoemForm/types';
import toast from 'react-hot-toast';
import { trackNotBirthdayClicked } from '../lib/analytics/events';
import { LanguageSwitcher } from '../components/LanguageSwitcher';
import { LanguageProvider } from '../contexts/LanguageContext';
import { useLanguage } from '../contexts/LanguageContext';
import { Loader2 } from 'lucide-react';

const API_URL = import.meta.env.VITE_API_URL || 'https://birthdaypoem-server.vercel.app';

function HomePageContent() {
  const [isLoading, setIsLoading] = React.useState(false);
  const [isPageLoading, setIsPageLoading] = React.useState(true);
  const [poem, setPoem] = React.useState<string | null>(null);
  const [poemId, setPoemId] = React.useState<string | null>(null);
  const [recipientName, setRecipientName] = React.useState<string>('');
  const [showModal, setShowModal] = React.useState(false);
  const { language } = useLanguage();

  React.useEffect(() => {
    // Simulate checking for any necessary resources/data
    const timer = setTimeout(() => {
      setIsPageLoading(false);
    }, 500);
    return () => clearTimeout(timer);
  }, []);

  const handleNotBirthdayClick = () => {
    trackNotBirthdayClicked();
    setShowModal(true);
  };

  const handleSubmit = async (data: PoemFormData) => {
    setIsLoading(true);
    setRecipientName(data.name);

    try {
      // Generate ID first
      const newPoemId = generateId();
      setPoemId(newPoemId);

      // Generate the poem
      const response = await fetch(`${API_URL}/api/generate-poem`, {
        method: 'POST',
        headers: {
          'Content-Type': 'application/json',
          'Accept': 'application/json'
        },
        credentials: 'include',
        body: JSON.stringify({
          ...data,
          poemId: newPoemId,
          language
        }),
      });

      if (!response.ok) {
        throw new Error('Failed to generate poem');
      }

      const result = await response.json();
      setPoem(result.poem);
      
      // Store in localStorage using safe utilities
      storage.set(newPoemId, result.poem);
      storage.set(`${newPoemId}_name`, data.name);
      storage.set(`${newPoemId}_language`, language);
      
      // Scroll to poem using safe utility
      setTimeout(scrollToPoem, 100);
    } catch (error) {
      console.error('Error:', error);
      toast.error('Failed to generate poem. Please try again.');
    } finally {
      setIsLoading(false);
    }
  };

  if (isPageLoading) {
    return (
      <div className="min-h-screen bg-gradient-to-b from-purple-50 to-white flex items-center justify-center">
        <Loader2 className="w-12 h-12 animate-[spin_1s_ease-in-out_infinite] text-purple-600" />
      </div>
    );
  }

  return (
    <div className="min-h-screen bg-gradient-to-b from-purple-50 to-white">
      <div className="max-w-7xl mx-auto px-4 py-6">
        <div className="flex justify-between items-center mb-12" dir="ltr">
          <Logo />
          <LanguageSwitcher currentLanguage={language} />
        </div>
        <div className="flex flex-col items-center space-y-12">
          <StaticHeader
            title="Create a Beautiful Birthday Poem"
            description="Generate a personalized birthday poem for your loved ones using AI. Just fill in a few details and we'll create a unique poem that captures your feelings."
            language={language}
            onNotBirthdayClick={handleNotBirthdayClick}
          />
          <PoemForm onSubmit={handleSubmit} isLoading={isLoading} language={language} />
          {poem && (
            <div id="poem-display" className="w-full max-w-2xl relative">
              <PoemDisplay 
                poem={poem} 
                recipientName={recipientName}
                poemId={poemId} 
              />
            </div>
          )}
        </div>
      </div>
      <Footer />
      {/* Coming Soon Modal */}
      {showModal && (
        <div className="fixed inset-0 bg-black bg-opacity-50 flex items-center justify-center z-50">
          <div className="bg-white rounded-lg p-8 max-w-md w-full mx-4 relative">
            <button
              onClick={() => setShowModal(false)}
              className="absolute top-4 right-4 text-gray-500 hover:text-gray-700"
            >
              <svg className="w-6 h-6" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M6 18L18 6M6 6l12 12" />
              </svg>
            </button>
            <h2 className="text-2xl font-bold text-gray-900 mb-4">
              {language === 'he' ? 'בקרוב!' : 'Coming Soon!'}
            </h2>
            <p className="text-gray-600">
              {language === 'he' 
                ? 'אנחנו עובדים על הרחבת סוגי השירים שלנו כדי לכלול שירי יום נישואין, שירי אהבה, שירי ברכה ועוד. בדוק שוב בקרוב!'
                : 'We\'re working on expanding our poem types to include anniversary poems, love poems, congratulation poems, and more. Check back soon!'
              }
            </p>
          </div>
        </div>
      )}
    </div>
  );
}

export function HomePage() {
  return (
    <LanguageProvider initialLanguage="en">
      <HomePageContent />
    </LanguageProvider>
  );
}